@@ -2,7 +2,7 @@ package Test2::Compare::Base;
 use strict;
 use warnings;
 
-our $VERSION = '0.000060';
+our $VERSION = '0.000061';
 
 use Carp qw/confess croak/;
 use Scalar::Util qw/blessed/;
@@ -30,8 +30,8 @@ sub clone {
 
 sub init {
     my $self = shift;
-    $self->{_lines} = delete $self->{lines} if exists $self->{lines};
-    $self->{_file}  = delete $self->{file}  if exists $self->{file};
+    $self->{+_LINES} = delete $self->{lines} if exists $self->{lines};
+    $self->{+_FILE}  = delete $self->{file}  if exists $self->{file};
 }
 
 sub file {
