@@ -2,7 +2,7 @@ package Test2::Util::Table;
 use strict;
 use warnings;
 
-our $VERSION = '0.000058';
+our $VERSION = '0.000061';
 
 use Test2::Util::Table::LineBreak();
 
@@ -24,10 +24,12 @@ sub term_size {
     my $total;
     try {
         my @warnings;
-        local $SIG{__WARN__} = sub { push @warnings => @_ };
-        ($total) = Term::ReadKey::GetTerminalSize(*STDOUT);
+        {
+            local $SIG{__WARN__} = sub { push @warnings => @_ };
+            ($total) = Term::ReadKey::GetTerminalSize(*STDOUT);
+        }
         @warnings = grep { $_ !~ m/Unable to get Terminal Size/ } @warnings;
-        warn @warnings;
+        warn @warnings if @warnings;
     };
     return 80 if !$total;
     return 80 if $total < 80;
